.. :changelog:

History
-------

0.8.1 (2014-01-10)
++++++++++++++++++

* setup.py refatorado
* adicionado arquivos de licença, contribuidores, historico e como contribuir
* modificado urls.py para tentar importar primeiro as funcoes do django > 1.4


0.5.0 (2011)
++++++++++++++++++
* First release on PyPI.
